@@ -8,18 +8,17 @@ use Data::Dumper;
 use Math::Symbolic qw/:all/;
 
 my $var = Math::Symbolic::Variable->new();
-my $a = $var->new('x' => 3.14159);
+my $a   = $var->new( 'x' => 3.14159 );
 
-my $c = Math::Symbolic::Constant->new();
+my $c   = Math::Symbolic::Constant->new();
 my $two = $c->new(2);
 
-print "Vars: x=" . $a->value() .
-           " (Value is optional)\n\n";
+print "Vars: x=" . $a->value() . " (Value is optional)\n\n";
+
+my $op = Math::Symbolic::Operator->new();
 
-my $op  = Math::Symbolic::Operator->new();
 #my $sin = $op->new('sin', $op->new('*', $two, $a));
-my $sin = $op->new('sinh', $op->new('*', $two, $a));
-
+my $sin = $op->new( 'sinh', $op->new( '*', $two, $a ) );
 
 print "Expression: sinh(2*x)\n\n";
 
@@ -28,10 +27,12 @@ print $sin->to_string('prefix') . " = " . $sin->value() . "\n\n";
 
 print "Now, we derive this partially to x: (prefix again)\n";
 
-my $n_tree = $op->new( {
-	type => U_P_DERIVATIVE,
-	operands => [$sin, $a],
-} );
+my $n_tree = $op->new(
+    {
+        type     => U_P_DERIVATIVE,
+        operands => [ $sin, $a ],
+    }
+);
 
 print $n_tree->to_string('prefix') . " = " . $sin->value() . "\n\n";
 
@@ -44,15 +45,15 @@ print "Finally, we simplify the derived term as much as possible:\n";
 $derived = $derived->simplify();
 print "$derived = " . $derived->value() . "\n\n";
 
-
 print "Now, we do this three more times:\n";
-for (1..3) {
-	$derived = $op->new( {
-		type => U_P_DERIVATIVE,
-		operands => [$derived, $a],
-	} )->apply_derivatives()->simplify();
+for ( 1 .. 3 ) {
+    $derived = $op->new(
+        {
+            type     => U_P_DERIVATIVE,
+            operands => [ $derived, $a ],
+        }
+    )->apply_derivatives()->simplify();
 }
 
 print "$derived = " . $derived->value() . "\n\n";
 
-
